@@ -4,14 +4,24 @@ controls.py - support classes for LDAP controls
 
 See https://www.python-ldap.org/ for details.
 
-$Id: __init__.py,v 1.11 2017/08/15 16:21:58 stroeder Exp $
-
 Description:
 The ldap.controls module provides LDAPControl classes.
 Each class provides support for a certain control.
 """
 
-from ldap import __version__
+from ldap.pkginfo import __version__
+
+import _ldap
+assert _ldap.__version__==__version__, \
+       ImportError('ldap %s and _ldap %s version mismatch!' % (__version__,_ldap.__version__))
+
+import ldap
+
+try:
+  from pyasn1.error import PyAsn1Error
+except ImportError:
+  PyAsn1Error = None
+
 
 __all__ = [
   'KNOWN_RESPONSE_CONTROLS',
@@ -34,13 +44,6 @@ __all__ = [
 # response control OID to class registry
 KNOWN_RESPONSE_CONTROLS = {}
 
-import _ldap,ldap
-
-try:
-  from pyasn1.error import PyAsn1Error
-except ImportError:
-  PyAsn1Error = None
-
 
 class RequestControl:
   """
@@ -145,7 +148,7 @@ def DecodeControlTuples(ldapControlTuples,knownLDAPControls=None):
       control.controlType,control.criticality = controlType,criticality
       try:
         control.decodeControlValue(encodedControlValue)
-      except PyAsn1Error,e:
+      except PyAsn1Error as e:
         if criticality:
           raise e
       else:
