@@ -1,15 +1,14 @@
-/* See https://www.python-ldap.org/ for details.
- * $Id: LDAPObject.h,v 1.11 2017/08/15 16:21:59 stroeder Exp $ */
+/* See https://www.python-ldap.org/ for details. */
 
-#ifndef __h_LDAPObject 
-#define __h_LDAPObject 
+#ifndef __h_LDAPObject
+#define __h_LDAPObject
 
 #include "common.h"
 
 #include "lber.h"
 #include "ldap.h"
-#if LDAP_API_VERSION < 2000
-#error Current python-ldap requires OpenLDAP 2.x
+#if LDAP_API_VERSION < 2040
+#error Current python-ldap requires OpenLDAP 2.4.x
 #endif
 
 #if PYTHON_API_VERSION < 1007
@@ -26,7 +25,7 @@ typedef struct {
 } LDAPObject;
 
 extern PyTypeObject LDAP_Type;
-#define LDAPObject_Check(v)     ((v)->ob_type == &LDAP_Type)
+#define LDAPObject_Check(v)     (Py_TYPE(v) == &LDAP_Type)
 
 extern LDAPObject *newLDAPObject( LDAP* );
 
