@@ -1,8 +1,8 @@
 /* common utility macros
  * See https://www.python-ldap.org/ for details. */
 
-#ifndef __h_common 
-#define __h_common 
+#ifndef __h_common
+#define __h_common
 
 #define PY_SSIZE_T_CLEAN
 
@@ -20,13 +20,6 @@
 #include <sys/types.h>
 #endif
 
-/* Backwards compability with Python prior 2.5 */
-#if PY_VERSION_HEX < 0x02050000
-typedef int Py_ssize_t;
-#define PY_SSIZE_T_MAX INT_MAX
-#define PY_SSIZE_T_MIN INT_MIN
-#endif
-
 #include <string.h>
 #define streq( a, b ) \
 	( (*(a)==*(b)) && 0==strcmp(a,b) )
@@ -34,5 +27,8 @@ typedef int Py_ssize_t;
 void LDAPadd_methods( PyObject*d, PyMethodDef*methods );
 #define PyNone_Check(o) ((o) == Py_None)
 
-#endif /* __h_common_ */
+#if PY_MAJOR_VERSION >= 3
+#define PyInt_FromLong PyLong_FromLong
+#endif
 
+#endif /* __h_common_ */
