@@ -27,13 +27,13 @@ LDAPControl_DumpList( LDAPControl** lcs ) {
 } */
 
 /* Free a single LDAPControl object created by Tuple_to_LDAPControl */
-  
+
 static void
 LDAPControl_DEL( LDAPControl* lc )
 {
     if (lc == NULL)
         return;
-  
+
     if (lc->ldctl_oid)
         PyMem_DEL(lc->ldctl_oid);
     PyMem_DEL(lc);
@@ -79,7 +79,7 @@ Tuple_to_LDAPControl( PyObject* tup )
 
     if (!PyArg_ParseTuple( tup, "sbO", &oid, &iscritical, &bytes ))
         return NULL;
-  
+
     lc = PyMem_NEW(LDAPControl, 1);
     if (lc == NULL) {
         PyErr_NoMemory();
@@ -102,17 +102,17 @@ Tuple_to_LDAPControl( PyObject* tup )
         berbytes.bv_len = 0;
         berbytes.bv_val = NULL;
     }
-    else if (PyString_Check(bytes)) {
-        berbytes.bv_len = PyString_Size(bytes);
-        berbytes.bv_val = PyString_AsString(bytes);
+    else if (PyBytes_Check(bytes)) {
+        berbytes.bv_len = PyBytes_Size(bytes);
+        berbytes.bv_val = PyBytes_AsString(bytes);
     }
     else {
 	PyErr_SetObject(PyExc_TypeError, Py_BuildValue("sO",
-            "expected a string", bytes));
+            "expected a byte-string", bytes));
         LDAPControl_DEL(lc);
         return NULL;
     }
-    
+
     lc->ldctl_value = berbytes;
 
     return lc;
@@ -128,7 +128,7 @@ LDAPControls_from_object(PyObject* list, LDAPControl ***controls_ret)
     LDAPControl** ldcs;
     LDAPControl* ldc;
     PyObject* item;
-  
+
     if (!PySequence_Check(list)) {
 	PyErr_SetObject(PyExc_TypeError, Py_BuildValue("sO",
 	   "expected a list", list));
