@@ -1,5 +1,4 @@
-/* See https://www.python-ldap.org/ for details.
- * $Id: message.c,v 1.20 2017/08/15 16:21:59 stroeder Exp $ */
+/* See https://www.python-ldap.org/ for details. */
 
 #include "common.h"
 #include "message.h"
@@ -48,8 +47,8 @@ LDAPmessage_to_python(LDAP *ld, LDAPMessage *m, int add_ctrls, int add_intermedi
 	 char *dn;
 	 char *attr;
 	 BerElement *ber = NULL;
-	 PyObject* entrytuple; 
-	 PyObject* attrdict; 
+	 PyObject* entrytuple;
+	 PyObject* attrdict;
 
 	 dn = ldap_get_dn( ld, entry );
 	 if (dn == NULL)  {
@@ -100,7 +99,7 @@ LDAPmessage_to_python(LDAP *ld, LDAPMessage *m, int add_ctrls, int add_intermedi
 		 valuelist = PyMapping_GetItemString( attrdict, attr );
 	     } else {
 		 valuelist = PyList_New(0);
-		 if (valuelist != NULL && PyMapping_SetItemString(attrdict, 
+		 if (valuelist != NULL && PyMapping_SetItemString(attrdict,
 		     attr, valuelist) == -1) {
 			Py_DECREF(valuelist);
 			valuelist = NULL;	/* catch error later */
@@ -192,7 +191,7 @@ LDAPmessage_to_python(LDAP *ld, LDAPMessage *m, int add_ctrls, int add_intermedi
 	 if (refs) {
 	     Py_ssize_t i;
 	     for (i=0; refs[i] != NULL; i++) {
-		 PyObject *refstr = PyString_FromString(refs[i]);
+		 PyObject *refstr = PyBytes_FromString(refs[i]);
 		 PyList_Append(reflist, refstr);
 		 Py_DECREF(refstr);
 	     }
