@@ -23,7 +23,7 @@ option_error(int res, const char *fn)
         PyErr_SetString(PyExc_ValueError, "option error");
     else if (res == LDAP_PARAM_ERROR)
         PyErr_SetString(PyExc_ValueError, "parameter error");
-    else if (res == LDAP_NO_MEMORY) 
+    else if (res == LDAP_NO_MEMORY)
         PyErr_NoMemory();
     else
         PyErr_Format(PyExc_SystemError, "error %d from %s", res, fn);
@@ -156,14 +156,14 @@ LDAP_set_option(LDAPObject *self, int option, PyObject *value)
 	    PyErr_Format(PyExc_ValueError, "unknown option %d", option);
 	    return 0;
     }
-	
+
     if (self) LDAP_BEGIN_ALLOW_THREADS(self);
     res = ldap_set_option(ld, option, ptr);
     if (self) LDAP_END_ALLOW_THREADS(self);
 
     if ((option == LDAP_OPT_SERVER_CONTROLS) || (option == LDAP_OPT_CLIENT_CONTROLS))
         LDAPControl_List_DEL(controls);
-    
+
     if (res != LDAP_OPT_SUCCESS) {
         option_error(res, "ldap_set_option");
         return 0;
@@ -196,7 +196,7 @@ LDAP_get_option(LDAPObject *self, int option)
 	    if (self) LDAP_END_ALLOW_THREADS(self);
 	    if (res != LDAP_OPT_SUCCESS)
 		return option_error(res, "ldap_get_option");
-    
+
 	    /* put the extensions into tuple form */
 	    num_extensions = 0;
 	    while (apiinfo.ldapai_extensions[num_extensions])
@@ -204,7 +204,7 @@ LDAP_get_option(LDAPObject *self, int option)
 	    extensions = PyTuple_New(num_extensions);
 	    for (i = 0; i < num_extensions; i++)
 		PyTuple_SET_ITEM(extensions, i,
-		    PyString_FromString(apiinfo.ldapai_extensions[i]));
+		    PyBytes_FromString(apiinfo.ldapai_extensions[i]));
 
 	    /* return api info as a dictionary */
 	    v = Py_BuildValue("{s:i, s:i, s:i, s:s, s:i, s:O}",
@@ -321,7 +321,7 @@ LDAP_get_option(LDAPObject *self, int option)
 		Py_INCREF(Py_None);
 		return Py_None;
 	    }
-	    v = PyString_FromString(strval);
+	    v = PyBytes_FromString(strval);
 	    ldap_memfree(strval);
 	    return v;
 
@@ -354,7 +354,7 @@ LDAP_get_option(LDAPObject *self, int option)
 
             if (lcs == NULL)
                 return PyList_New(0);
-            
+
             /* Get the number of controls */
             num_controls = 0;
             while (lcs[num_controls])
@@ -364,17 +364,17 @@ LDAP_get_option(LDAPObject *self, int option)
             v = PyList_New(num_controls);
             for (i = 0; i < num_controls; i++) {
                 lc = lcs[i];
-                tup = Py_BuildValue("(sbs)", 
+                tup = Py_BuildValue("(sbs)",
                                     lc->ldctl_oid,
                                     lc->ldctl_iscritical,
                                     lc->ldctl_value.bv_val);
                 PyList_SET_ITEM(v, i, tup);
             }
-            
+
             ldap_controls_free(lcs);
 
             return v;
-            
+
     default:
 	    PyErr_Format(PyExc_ValueError, "unknown option %d", option);
 	    return NULL;
