@@ -39,8 +39,9 @@ class TestCidict(unittest.TestCase):
         cix_items.sort()
         self.assertEqual(cix_items, [('AbCDeF',123), ('xYZ',987)])
         del cix["abcdEF"]
-        self.assertEqual(cix._keys.has_key("abcdef"), False)
-        self.assertEqual(cix._keys.has_key("AbCDef"), False)
+        self.assertEqual("abcdef" in cix, False)
+        self.assertEqual("AbCDef" in cix._keys, False)
+        self.assertEqual(cix.has_key("abcdef"), False)
 
 
 if __name__ == '__main__':
