@@ -7,6 +7,7 @@ See https://www.python-ldap.org/ for details.
 
 import os
 import unittest
+import pickle
 from slapdtest import SlapdTestCase
 
 # Switch off processing .ldaprc or ldap.conf before importing _ldap
@@ -27,6 +28,12 @@ objectClass: simpleSecurityObject
 cn: %(rootcn)s
 userPassword: %(rootpw)s
 
+dn: cn=user1,%(suffix)s
+objectClass: applicationProcess
+objectClass: simpleSecurityObject
+cn: user1
+userPassword: user1_pw
+
 dn: cn=Foo1,%(suffix)s
 objectClass: organizationalRole
 cn: Foo1
@@ -50,7 +57,7 @@ cn: Foo4
 """
 
 
-class Test01_SimpleLDAPObject(SlapdTestCase):
+class Test00_SimpleLDAPObject(SlapdTestCase):
     """
     test LDAP search operations
     """
@@ -59,7 +66,7 @@ class Test01_SimpleLDAPObject(SlapdTestCase):
 
     @classmethod
     def setUpClass(cls):
-        SlapdTestCase.setUpClass()
+        super(Test00_SimpleLDAPObject, cls).setUpClass()
         # insert some Foo* objects via ldapadd
         cls.server.ldapadd(
             LDIF_TEMPLATE % {
@@ -78,7 +85,7 @@ class Test01_SimpleLDAPObject(SlapdTestCase):
             # open local LDAP connection
             self._ldap_conn = self._open_ldap_conn()
 
-    def test_search_subtree(self):
+    def test001_search_subtree(self):
         result = self._ldap_conn.search_s(
             self.server.suffix,
             ldap.SCOPE_SUBTREE,
@@ -108,7 +115,7 @@ class Test01_SimpleLDAPObject(SlapdTestCase):
             ]
         )
 
-    def test_search_onelevel(self):
+    def test002_search_onelevel(self):
         result = self._ldap_conn.search_s(
             self.server.suffix,
             ldap.SCOPE_ONELEVEL,
@@ -134,7 +141,7 @@ class Test01_SimpleLDAPObject(SlapdTestCase):
             ]
         )
 
-    def test_search_oneattr(self):
+    def test003_search_oneattr(self):
         result = self._ldap_conn.search_s(
             self.server.suffix,
             ldap.SCOPE_SUBTREE,
@@ -147,12 +154,12 @@ class Test01_SimpleLDAPObject(SlapdTestCase):
             [('cn=Foo4,ou=Container,'+self.server.suffix, {'cn': ['Foo4']})]
         )
 
-    def test_errno107(self):
+    def test004_errno107(self):
         l = self.ldap_object_class('ldap://127.0.0.1:42')
         try:
             m = l.simple_bind_s("", "")
             r = l.result4(m, ldap.MSG_ALL, self.timeout)
-        except ldap.SERVER_DOWN, ldap_err:
+        except ldap.SERVER_DOWN as ldap_err:
             errno = ldap_err.args[0]['errno']
             if errno != 107:
                 self.fail("expected errno=107, got %d" % errno)
@@ -162,7 +169,7 @@ class Test01_SimpleLDAPObject(SlapdTestCase):
         else:
             self.fail("expected SERVER_DOWN, got %r" % r)
 
-    def test_invalid_credentials(self):
+    def test005_invalid_credentials(self):
         l = self.ldap_object_class(self.server.ldap_uri)
         # search with invalid filter
         try:
@@ -173,7 +180,7 @@ class Test01_SimpleLDAPObject(SlapdTestCase):
         else:
             self.fail("expected INVALID_CREDENTIALS, got %r" % r)
 
-    def test_sasl_extenal_bind_s(self):
+    def test006_sasl_extenal_bind_s(self):
         l = self.ldap_object_class(self.server.ldapi_uri)
         l.sasl_external_bind_s()
         self.assertEqual(l.whoami_s(), 'dn:'+self.server.root_dn.lower())
@@ -181,15 +188,73 @@ class Test01_SimpleLDAPObject(SlapdTestCase):
         l = self.ldap_object_class(self.server.ldapi_uri)
         l.sasl_external_bind_s(authz_id=authz_id)
         self.assertEqual(l.whoami_s(), authz_id.lower())
+
+    def test007_timeout(self):
+        l = self.ldap_object_class(self.server.ldap_uri)
+        m = l.search_ext(self.server.suffix, ldap.SCOPE_SUBTREE, '(objectClass=*)')
+        l.abandon(m)
+        with self.assertRaises(ldap.TIMEOUT):
+            result = l.result(m, timeout=0.001)
         
 
-class Test02_ReconnectLDAPObject(Test01_SimpleLDAPObject):
+class Test01_ReconnectLDAPObject(Test00_SimpleLDAPObject):
     """
-    test LDAP search operations
+    test ReconnectLDAPObject by restarting slapd
     """
 
     ldap_object_class = ReconnectLDAPObject
 
+    def test101_reconnect_sasl_external(self):
+        l = self.ldap_object_class(self.server.ldapi_uri)
+        l.sasl_external_bind_s()
+        authz_id = l.whoami_s()
+        self.assertEqual(authz_id, 'dn:'+self.server.root_dn.lower())
+        self.server.restart()
+        self.assertEqual(l.whoami_s(), authz_id)
+
+    def test102_reconnect_simple_bind(self):
+        l = self.ldap_object_class(self.server.ldapi_uri)
+        bind_dn = 'cn=user1,'+self.server.suffix
+        l.simple_bind_s(bind_dn, 'user1_pw')
+        self.assertEqual(l.whoami_s(), 'dn:'+bind_dn)
+        self.server.restart()
+        self.assertEqual(l.whoami_s(), 'dn:'+bind_dn)
+
+    def test103_reconnect_get_state(self):
+        l1 = self.ldap_object_class(self.server.ldapi_uri)
+        bind_dn = 'cn=user1,'+self.server.suffix
+        l1.simple_bind_s(bind_dn, 'user1_pw')
+        self.assertEqual(l1.whoami_s(), 'dn:'+bind_dn)
+        self.assertEqual(
+            l1.__getstate__(),
+            {
+                '_last_bind': (
+                    'simple_bind_s',
+                    (bind_dn, 'user1_pw'),
+                    {}
+                ),
+                '_options': [(17, 3)],
+                '_reconnects_done': 0,
+                '_retry_delay': 60.0,
+                '_retry_max': 1,
+                '_start_tls': 0,
+                '_trace_level': 0,
+                '_trace_stack_limit': 5,
+                '_uri': self.server.ldapi_uri,
+                'timeout': -1,
+            },
+        )
+
+    def test104_reconnect_restore(self):
+        l1 = self.ldap_object_class(self.server.ldapi_uri)
+        bind_dn = 'cn=user1,'+self.server.suffix
+        l1.simple_bind_s(bind_dn, 'user1_pw')
+        self.assertEqual(l1.whoami_s(), 'dn:'+bind_dn)
+        l1_state = pickle.dumps(l1)
+        del l1
+        l2 = pickle.loads(l1_state)
+        self.assertEqual(l2.whoami_s(), 'dn:'+bind_dn)
+
 
 if __name__ == '__main__':
     unittest.main()
